==> ux-reward-wrap-2.0.13.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Rewarded/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './rewarded.css';
import { rewardedFilter } from '../defaultData';
import Filter from '../../../../../components/common/componentTagFilter';
import RewardedList from './RewardedList';
import { taker, getApiUrl } from '../../../../../helper';
import Nodata from '../../../../../components/common/noDataView';

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: 'reward',
      data: 'rewardwrap'
    }
  }));
  return React.createElement("span", {
    className: 'go-reward',
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u5C1D\u8BD5\u6253\u8D4F");
}

var RewardWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardWrap, _React$Component);

  function RewardWrap() {
    var _this;

    _classCallCheck(this, RewardWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));
    _this.state = {
      selectedFilter: 0
    };

    _this.getData = function (k) {
      var url = getApiUrl("proxy/GetUPaaSCoreGateway/Reward/GetLatestReward?scope=".concat(k));
      taker(url).then(function (res) {
        if (res.OperationResult) {
          _this.setState({
            rewardedDatas: res.OperationObject
          });
        }
      });
    };

    _this.handleFilter = function (k) {
      _this.getData(k);

      _this.setState({
        selectedFilter: k
      });
    };

    return _this;
  }

  _createClass(RewardWrap, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getData(0);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          selectedFilter = _this$state.selectedFilter,
          rewardedDatas = _this$state.rewardedDatas;
      var goReward = this.props.goReward;
      if (selectedFilter == 0 && (!rewardedDatas || !rewardedDatas.length)) return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      }));
      return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Filter, {
        tagData: rewardedFilter,
        handleClick: this.handleFilter,
        selectexIndex: selectedFilter
      }), rewardedDatas && rewardedDatas.length ? React.createElement(RewardedList, {
        rewardedData: rewardedDatas,
        goReward: goReward
      }) : React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      })));
    }
  }]);

  return RewardWrap;
}(React.Component);

export { RewardWrap as default };

==> ux-reward-wrap-3.0.3.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Rewarded/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './rewarded.css';
import { rewardedFilter } from '../defaultData';
import Filter from '../../../../../components/common/componentTagFilter';
import RewardedList from './RewardedList';
import { takerCloud } from '../../../../../helper';
import { getCloudApiUrl } from '../../../../../helper/getCloudApi';
import Nodata from '../../../../../components/common/noDataView';

function GoReward(_ref) {
  var handleGoReward = _ref.handleGoReward;
  var dataUdc = encodeURIComponent(JSON.stringify({
    ext: {
      type: 'reward',
      data: 'rewardwrap'
    }
  }));
  return React.createElement("span", {
    className: 'go-reward',
    "data-udc": dataUdc,
    onClick: function onClick() {
      handleGoReward();
    }
  }, "\u5C1D\u8BD5\u6253\u8D4F");
}

var RewardWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardWrap, _React$Component);

  function RewardWrap() {
    var _this;

    _classCallCheck(this, RewardWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));
    _this.state = {
      selectedFilter: 0
    };

    _this.getData = function (k) {
      var url = getCloudApiUrl("/UPaaSCoreMRest/100000/Reward/GetLatestReward?scope=".concat(k));
      takerCloud(url).then(function (res) {
        if (res.OperationResult) {
          _this.setState({
            rewardedDatas: res.OperationObject
          });
        }
      });
    };

    _this.handleFilter = function (k) {
      _this.getData(k);

      _this.setState({
        selectedFilter: k
      });
    };

    return _this;
  }

  _createClass(RewardWrap, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getData(0);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          selectedFilter = _this$state.selectedFilter,
          rewardedDatas = _this$state.rewardedDatas;
      var goReward = this.props.goReward;
      if (selectedFilter == 0 && (!rewardedDatas || !rewardedDatas.length)) return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      }));
      return React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Filter, {
        tagData: rewardedFilter,
        handleClick: this.handleFilter,
        selectexIndex: selectedFilter
      }), rewardedDatas && rewardedDatas.length ? React.createElement(RewardedList, {
        rewardedData: rewardedDatas,
        goReward: goReward
      }) : React.createElement("div", {
        className: 'rewarded'
      }, React.createElement(Nodata, {
        icon: 1,
        text: "\u6682\u65E0\u5458\u5DE5\u83B7\u5F97\u6253\u8D4F"
      }), React.createElement(GoReward, {
        handleGoReward: goReward
      })));
    }
  }]);

  return RewardWrap;
}(React.Component);

export { RewardWrap as default };
